@@ -1,6 +1,6 @@
 package HTML::Mason::PSGIHandler;
 BEGIN {
-  $HTML::Mason::PSGIHandler::VERSION = '0.51';
+  $HTML::Mason::PSGIHandler::VERSION = '0.52';
 }
 use strict;
 use 5.008_001;
@@ -33,6 +33,14 @@ sub handle_psgi {
     $self->interp->out_method( \$output );
     $self->interp->delayed_object_params('request', cgi_request => $r);
 
+    my @result = $self->invoke_mason($r, $p);
+    die if $@;
+
+    return [ $r->psgi_header(-Status => $result[0]), [ defined $output ? $output : () ] ];
+}
+
+sub invoke_mason {
+    my ($self, $r, $p) = @_;
     my %args = $self->request_args($r);
 
     my @result;
@@ -44,9 +52,7 @@ sub handle_psgi {
         eval { $self->interp->exec($p->{comp}, %args) };
     }
 
-    die if $@;
-
-    return [ $r->psgi_header(-Status => $result[0]), [ defined $output ? $output : () ] ];
+    return @result;
 }
 
 sub HTML::Mason::FakeApache::psgi_header {
@@ -64,7 +70,7 @@ sub HTML::Mason::FakeApache::psgi_header {
 
 package HTML::Mason::Request::PSGI;
 BEGIN {
-  $HTML::Mason::Request::PSGI::VERSION = '0.51';
+  $HTML::Mason::Request::PSGI::VERSION = '0.52';
 }
 use strict;
 use base qw(HTML::Mason::Request::CGI);
